@@ -37,9 +37,11 @@ class TestScore(unittest.TestCase):
                 metrics_dicts[metrics.instance_id][metrics.summarizer_id] = metrics
 
                 if metrics.summarizer_type == 'reference':
+                    assert len(metrics.metrics) == 2
                     assert 'python-rouge-1_jk' in metrics.metrics
                     assert 'python-rouge-2_jk' in metrics.metrics
                 else:
+                    assert len(metrics.metrics) == 4
                     assert 'python-rouge-1' in metrics.metrics
                     assert 'python-rouge-2' in metrics.metrics
                     assert 'python-rouge-1_jk' in metrics.metrics
@@ -127,4 +129,66 @@ class TestScore(unittest.TestCase):
             # test_jk = 100 * 10 + 100 * 1000 == 101000
             assert metrics_list[3].metrics == {'test_jk': 101000}  # 100 * 10 + 100 * 1000
             # test_jk = 1000 * 10 + 10000 * 100 == 110000
-            assert metrics_list[4].metrics == {'test_jk': 110000}  # 1000 * 10 + 10000 * 100
\ No newline at end of file
+            assert metrics_list[4].metrics == {'test_jk': 110000}  # 1000 * 10 + 10000 * 100
+
+    def test_disable_jackknifing(self):
+        with TemporaryDirectory() as temp_dir:
+            # Runs a regression test for the "score" command
+            output_file = f'{temp_dir}/metrics.jsonl'
+            command = [
+                'python', '-m', 'sacrerouge', 'score',
+                _config_file_path,
+                output_file,
+                '--disable-peer-jackknifing'
+            ]
+
+            process = Popen(command, stdout=PIPE, stderr=PIPE)
+            process.communicate()
+
+            instances = JsonlReader(MULTILING_SUMMARIES).read()
+            metrics_list = JsonlReader(output_file, Metrics).read()
+            metrics_dicts = defaultdict(dict)
+
+            assert len(instances) == len(metrics_list)
+            for instance, metrics in zip(instances, metrics_list):
+                assert metrics.instance_id == instance['instance_id']
+                assert metrics.summarizer_id == instance['summarizer_id']
+                assert metrics.summarizer_type == instance['summarizer_type']
+                metrics_dicts[metrics.instance_id][metrics.summarizer_id] = metrics
+
+                if metrics.summarizer_type == 'reference':
+                    assert len(metrics.metrics) == 2
+                    assert 'python-rouge-1_jk' in metrics.metrics
+                    assert 'python-rouge-2_jk' in metrics.metrics
+                else:
+                    assert len(metrics.metrics) == 2
+                    assert 'python-rouge-1' in metrics.metrics
+                    assert 'python-rouge-2' in metrics.metrics
+
+            # Test a couple of instances. I did not check to see if these are correct,
+            # but the test will check if the results have changed
+            assert metrics_dicts['M000']['1'].metrics == {
+                "python-rouge-1": {
+                  "precision": 41.699867197875164,
+                  "recall": 40.516129032258064,
+                  "f1": 41.09947643979057
+                },
+                "python-rouge-2": {
+                  "precision": 10.533333333333333,
+                  "recall": 10.233160621761659,
+                  "f1": 10.38107752956636
+                }
+            }
+
+            assert metrics_dicts['M001']['B'].metrics == {
+                "python-rouge-1_jk": {
+                  "precision": 51.59362549800797,
+                  "recall": 51.18577075098815,
+                  "f1": 51.3888888888889
+                },
+                "python-rouge-2_jk": {
+                  "precision": 20.4,
+                  "recall": 20.238095238095237,
+                  "f1": 20.318725099601597
+                }
+            }
\ No newline at end of file
